// Black Border Effect
//
// Copyright Outerspace Software, all rights reserved

string description = "This effect adds a black border to your textures.";

//texture0: the background texture
//texture1: not used

float4x4	WorldViewProjection;	
float4		UVBounds0 = float4(0,1,0,1);
float4		DiffuseCol;

//Tweakables
float	BorderSize = 0.04;
float4	BorderColour=float4(0.1,0.1,0.1,1);

texture MyTexture0;
sampler MyTextureSampler0 = sampler_state{
    Texture   = (MyTexture0);
    AddressU  = CLAMP;
    AddressV  = CLAMP;
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

struct VS_INPUT{
	float4 position:	POSITION;
	float3 normal:		NORMAL;
	float3 diffuse:		COLOR;
	float2 tex:			TEXCOORD0;
};

struct VS_OUTPUT{
	float4 position:	POSITION;
	float2 tex:			TEXCOORD0;
};

struct PS_OUTPUT{
    float4 color:		COLOR;
};

VS_OUTPUT VS(VS_INPUT input){
	VS_OUTPUT output;      
	output.position = mul(input.position, WorldViewProjection);
	output.tex = input.tex;
	return output;
}

PS_OUTPUT PS(VS_OUTPUT input){
	PS_OUTPUT output;

	float2 t=input.tex;

	bool b=false;
	if(abs(t.x-UVBounds0.x) < BorderSize) b=true;	
	else if(abs(t.x-UVBounds0.y) < BorderSize) b=true;	
	else if(abs(t.y-UVBounds0.z) < BorderSize) b=true;	
	else if(abs(t.y-UVBounds0.w) < BorderSize) b=true;

	if(UVBounds0.x<UVBounds0.y)
		t.x=UVBounds0.x + (t.x-BorderSize)/(UVBounds0.y-UVBounds0.x-2*BorderSize);
	else
		t.x=UVBounds0.y + (t.x-BorderSize)/(UVBounds0.x-UVBounds0.y-2*BorderSize);

	if(UVBounds0.z<UVBounds0.w)
		t.y=UVBounds0.z + (t.y-BorderSize)/(UVBounds0.w-UVBounds0.z-2*BorderSize);
	else
		t.y=UVBounds0.w + (t.y-BorderSize)/(UVBounds0.z-UVBounds0.w-2*BorderSize);

	float4 r;
	if(!b)
		r=tex2D(MyTextureSampler0, t);		
	else
		r=BorderColour;
		
	output.color = r;    
	return output;
}

technique Shader
{
    pass P0
    {
		VertexShader	= compile vs_1_1 VS();
		PixelShader		= compile ps_2_0 PS();
    }
}
