// SketchMap_Automatic Effect
//
// Copyright Outerspace Software, all rights reserved
//
// The difference with the standard SketchMap.fx generated by Bixelangelo
// is that this effect file animates the sketch automatically
// instead of controlled by the TRANSPARENCY property

string description = "Automatic Sketcher Effect";

float4x4	WorldViewProjection;
float4		MyTextureResolution0 = float4(256,256,1,0);
float		Time=0;

//Tweakables
float		DurationSketching	= 4;	//this should be the same as the "Photo View Time in Seconds" variable in the export as movie dialog of Bix's Photo Book
float		DurationViewing		= 4;
float4		SketchColour = float4(0,0,0,1);

texture MyTexture0;
sampler MyTextureSampler0 = sampler_state
{
   Texture = <MyTexture0>;
   MinFilter = None;
   MagFilter = None;
   MipFilter = None;   
   AddressU  = Clamp;
   AddressV  = Clamp;
};

struct VS_INPUT{
	float4 position:	POSITION;
	float3 normal:		NORMAL;
	float3 diffuse:		COLOR;
	float2 tex:		TEXCOORD0;
};

struct VS_OUTPUT{
	float4 position:	POSITION;
	float4 diffuse:		COLOR;
	float2 tex:		TEXCOORD0;
};

struct PS_OUTPUT{
    float4 color:		COLOR;
};

VS_OUTPUT VS(VS_INPUT input){
	VS_OUTPUT output;

	output.position = mul(input.position, WorldViewProjection);
	output.tex = input.tex;
	output.diffuse = float4(1,1,1,1);
	return output;
}

float GetT(float2 inUV){
	float3 p = tex2D(MyTextureSampler0, inUV);
	float  t = p.x*65536 + p.y*256 + p.z;

	float tt = Time % (DurationSketching+DurationViewing);
	if(tt>=DurationSketching) tt=1; else tt*=(1.0/DurationSketching);

	float b = tt * 65793;

	float r=0;
	if(t<b) r=1;
// if(p.x==1 && p.y==1 && p.z==1) r=0;

	return r;
}

PS_OUTPUT PS(VS_OUTPUT input){
	PS_OUTPUT output;

	output.color = SketchColour;

	float dx = 1.0/MyTextureResolution0.x;
	float dy = 1.0/MyTextureResolution0.y;
	
	float t = GetT(input.tex);
	t+=GetT(input.tex+float2(dx,0));
	t+=GetT(input.tex+float2(0,dy));

	output.color.w = t * 0.333;
	return output;
}

technique Shader
{
	pass P0
	{
	ALPHABLENDENABLE	=	TRUE;
	SRCBLEND			=	SRCALPHA;
	DESTBLEND			=	INVSRCALPHA;
	ALPHAARG1[0]		=	DIFFUSE;
	ALPHAOP[0]			=	SELECTARG1;
	ALPHATESTENABLE		=	TRUE;
	ALPHAREF			=	1;
	ALPHAFUNC			=	GREATEREQUAL;

	Sampler[0] = (MyTextureSampler0);
	VertexShader = compile vs_1_1 VS();
	PixelShader  = compile ps_2_0 PS();
	}
}
